@@ -81,6 +81,41 @@ class ConstantStateStrategy(object):
 		return "ConstantStateStrategy(timeout=%r)" % self._timeout
 
 
+class NTimesStateStrategy(object):
+
+	def __init__(self, timeouts, postTimeout):
+		assert 0 < len(timeouts)
+		for timeout in timeouts:
+			assert 0 < timeout or timeout == UpdateStateMachine.INFINITE_PERIOD
+		assert 0 < postTimeout or postTimeout == UpdateStateMachine.INFINITE_PERIOD
+		self._timeouts = timeouts
+		self._postTimeout = postTimeout
+
+		self._attemptCount = 0
+
+	def initialize_state(self):
+		self._attemptCount = len(self._timeouts)
+
+	def reinitialize_state(self):
+		self._attemptCount = 0
+
+	def increment_state(self):
+		self._attemptCount += 1
+
+	@property
+	def timeout(self):
+		try:
+			return self._timeouts[self._attemptCount]
+		except IndexError:
+			return self._postTimeout
+
+	def __repr__(self):
+		return "NTimesStateStrategy(timeouts=%r, postTimeout=%r)" % (
+			self._timeouts,
+			self._postTimeout,
+		)
+
+
 class GeometricStateStrategy(object):
 
 	def __init__(self, init, min, max):
@@ -234,7 +269,7 @@ class UpdateStateMachine(StateMachine):
 		_moduleLogger.info("%s Transitioning from %s to %s" % (self._name, oldState, newState))
 
 		self._state = newState
-		self._reset_timers()
+		self._reset_timers(initialize=True)
 
 	@property
 	def state(self):
@@ -251,16 +286,23 @@ class UpdateStateMachine(StateMachine):
 	def _strategy(self):
 		return self._strategies[self._state]
 
+	@property
+	def maxTime(self):
+		return self._maxTime
+
 	@gtk_toolbox.log_exception(_moduleLogger)
 	def _request_reset_timers(self, *args):
 		self._reset_timers()
 
-	def _reset_timers(self):
+	def _reset_timers(self, initialize=False):
 		if self._timeoutId is None:
 			return # not started yet
 		_moduleLogger.info("%s Resetting State Machine" % (self._name, ))
 		self._stop_update()
-		self._strategy.reinitialize_state()
+		if initialize:
+			self._strategy.initialize_state()
+		else:
+			self._strategy.reinitialize_state()
 		self._schedule_update()
 
 	def _stop_update(self):
